# vim: set sw=4 ts=4 et:
#
# spec file for package ts
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ts
Version:        1.0
Release:        1.2
Summary:        Task Spool Batch System
License:        GPL-2.0+
Group:          Productivity/Other
URL:            http://viric.name/soft/ts/
Source:         http://viric.name/soft/ts/%{name}-%{version}.tar.gz
Patch1:         ts-optflags.patch
Patch2:         ts-fix-warnings.patch
BuildRequires:  gcc
BuildRequires:  glibc-devel
BuildRequires:  make

%description
task spooler is a Unix batch system where the tasks spooled run one after the
other.

Each user in each system has his own job queue. The tasks are run in the
correct context (that of enqueue) from any shell/process, and its
output/results can be easily watched. It is very useful when you know that
your commands depend on a lot of RAM, a lot of disk use, give a lot of output,
or for whatever reason it's better not to run them at the same time.

%prep
%setup -q
%patch1 -p1
%patch2

%build
make \
    %{?_smp_mflags} \
    OPTFLAGS="%{optflags}" \
    CC="gcc"

%install
%make_install PREFIX=%{buildroot}%{_prefix}

%files
%doc Changelog COPYING OBJECTIVES PORTABILITY PROTOCOL README TRICKS
%{_bindir}/ts
%{_mandir}/man1/ts.1*

%changelog
* Wed Oct 18 2017 aavindraa@gmail.com
- update to 1.0:
  * Respect TMPDIR for output files.
- includes change from 0.7.6:
  * Add -k (send SIGTERM to process group). Replacement for "kill -- -`ts -p`".
- Packaging changes:
  * Rebase ts-optflags.patch
  * Use make install macro
* Fri May 22 2015 pascal.bleser@opensuse.org
- update to 0.7.5:
  * fixing a bug about dangling processes, in case of using "ts -r"
* Mon Jul 30 2012 pascal.bleser@opensuse.org
- update to 0.7.3:
  * adds the option '-N' to set the number of slots required for a job to run
  * clean up spec file
* Sat Nov 19 2011 pascal.bleser@opensuse.org
- update to 0.7.2:
  * adds optional separation of stdout and stderr (-E)
* Thu Oct 13 2011 pascal.bleser@opensuse.org
- update to 0.7.1:
  * small security bugfix to protect against other users in the system
* Thu Sep  1 2011 pascal.bleser@opensuse.org
- update to 0.7.0:
  * now enqueuing will not block other queue operations, in the case of a full
    queue
  * the new -B parameter allows ts to fail enqueuing if the queue is full,
    instead of blocking
* Tue Oct  6 2009 pascal.bleser@opensuse.org
- update to 0.6.5:
  * fixes the remaining ts with -c or -t, if its pipe was broken
  * fixes a problem with -l where an error message was always created in the
    error log file
  * adds the ability to limit the amount of ts connections (TS_MAXCONN)
- changes from 0.6.4:
  * fix a problem with the -t and -c options, introduced in 0.6.3
* Thu Feb 19 2009 guru@unixtech.be
- update to 0.6.3:
  * a bug on -c and -t was fixed
  * support was added for arbitrary dependencies (-D)
  * version checking on the client-server protocol was added
  * the server was made to chdir to / to avoid umount problems
* Sat Dec 20 2008 guru@unixtech.be
- update to 0.6.2:
  * bugfixes were made for the -w option, for clients dying, and for the error
    log file
  * the -S option now returns the number of slots set
  * the -i option shows a detailed exit status
* Mon Nov  3 2008 guru@unixtech.be
- update to 0.6.1:
  * adds support for the TS_SLOTS env variable
  * removes references to /usr for nix
  * fixes "-m" and error handling
* Thu Jul 17 2008 guru@unixtech.be
- new upstream version
* Mon Apr 28 2008 guru@unixtech.be
- new upstream version:
  * several bugs related to -t, -w, -c, -r, and other options were fixed
  * the behavior of -c (cat) was changed so that it waits until the job is
    finished
* Wed Feb 13 2008 guru@unixtech.be
- new upstream version
* Thu Feb  7 2008 guru@unixtech.be
- new upstream version
* Fri Jan 18 2008 guru@unixtech.be
- new upstream version
* Tue Dec 25 2007 guru@unixtech.be
- added Authors information in description
- new upstream version:
  * labels were added with -L, which can be used to better distinguish commands
    on the queue list
  * per-job information was added and is readable through -i and configurable
    through TS_ENV
  * dependent enqueuing was added (-d), making it possible to conditionally run
    based on the last job's result
  * some bugs were fixed
* Mon Nov 12 2007 guru@unixtech.be
- moved to Packman
- new upstream version
* Sat Apr 14 2007 guru@unixtech.be
- new upstream version
* Fri Apr  6 2007 guru@unixtech.be
- added manpage
- new upstream version
- CHANGES: some bugs were fixed
- CHANGES: an error report system was added, so many errors are reported, and
  the user can send them to the developers
- CHANGES: stability was increased by protecting known flaw situations like
  race conditions and exceeded limits
* Tue Apr  3 2007 guru@unixtech.be
- new upstream version
- CHANGES: bash is no longer used for running the commands, avoiding character
  escaping nightmares
- CHANGES: command output can now be gzipped
- CHANGES: number of finished jobs in the queue can be limited with an
  environment variable
- CHANGES: an environment variable may define the Unix socket path
- CHANGES: job ID is now output to stdout if the job is backgrounded (which is
  nice for scripting)
- CHANGES: a flag was added for swapping two waiting jobs in the queue
- CHANGES: command output can now be sent by email when a job finishes
- CHANGES: a binary can now be run (with job parameters) at job finish
* Tue Mar 27 2007 guru@unixtech.be
- new package
